@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2018 Savonet team
+  Copyright 2003-2019 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
  *****************************************************************************)
 
@@ -432,97 +432,6 @@ let () =
                   Lang.bool (not (b <= t && t < a))
           | _ -> assert false)
 
-(** Math *)
-
-let () =
-  let t = Lang.int_t in
-    add_builtin "mod" ~cat:Math
-      ~descr:"Integer remainder. If y is not zero, x == (x / y) * y + x mod y, \
-              and abs(x mod y) <= abs(y)-1."
-      ["",t,None,None;"",t,None,None] t
-      (fun p ->
-         match p with
-         | ["",{Lang.value=Lang.Int a;_};"",{Lang.value=Lang.Int b;_}] ->
-               Lang.int (a mod b)
-           | _ -> assert false)
-
-let () =
-  let t = Lang.univ_t ~constraints:[Lang_types.Num] 1 in
-    add_builtin "~-" ~cat:Math ~descr:"Returns the opposite of its argument."
-      ["",t,None,None] t
-      (function
-         | ["",{ Lang.value = Lang.Int i;_}] -> Lang.int (~- i)
-         | ["",{ Lang.value = Lang.Float i;_}] -> Lang.float (~-. i)
-         | _ -> assert false)
-
-let () =
-  let t = Lang.univ_t ~constraints:[Lang_types.Num] 1 in
-    add_builtin "abs" ~cat:Math ~descr:"Absolute value."
-      [ "",t,None,None ] t
-      (fun p ->
-         match (snd (List.hd p)).Lang.value with
-           | Lang.Int i   -> Lang.int (abs i)
-           | Lang.Float i -> Lang.float (abs_float i)
-           | _ -> assert false)
-
-let () =
-  let t = Lang.univ_t ~constraints:[Lang_types.Num] 1 in
-  let register_op doc name op_int op_float =
-    add_builtin name ~cat:Math ~descr:(Printf.sprintf "%s of numbers." doc)
-      ["",t,None,None;"",t,None,None] t
-      (fun p ->
-         match p with
-           | ["",{Lang.value=Lang.Int a;_};"",{Lang.value=Lang.Int b;_}] ->
-               Lang.int (op_int a b)
-           | ["",{Lang.value=Lang.Float a;_};"",{Lang.value=Lang.Float b;_}] ->
-               Lang.float (op_float a b)
-           | _ -> assert false)
-  in
-    register_op "Multiplication" "*" ( * ) ( *. ) ;
-    register_op "Division" "/" (/) (/.) ;
-    register_op "Addition" "+" (+) (+.) ;
-    register_op "Substraction " "-" (-) (-.) ;
-    register_op "Exponentiation" "pow"
-      (fun a b -> int_of_float ((float_of_int a) ** float_of_int b)) ( ** )
-
-let () =
-  add_builtin "random.float" ~cat:Math ~descr:"Generate a random value."
-    (* TODO better default values *)
-    ["min",Lang.float_t,Some (Lang.float (-1000000.)),None;
-     "max",Lang.float_t,Some (Lang.float ( 1000000.)),None]
-    Lang.float_t
-    (fun p ->
-       let min = Lang.to_float (List.assoc "min" p) in
-       let max = Lang.to_float (List.assoc "max" p) in
-         Lang.float (Random.float (max -. min) +. min))
-
-let () =
-  add_builtin "random.int" ~cat:Math ~descr:"Generate a random value."
-    ["min",Lang.float_t,Some (Lang.int min_int),None;
-     "max",Lang.float_t,Some (Lang.int max_int),None]
-    Lang.int_t
-    (fun p ->
-       let min = Lang.to_int (List.assoc "min" p) in
-       let max = Lang.to_int (List.assoc "max" p) in
-         Lang.int (Random.int (max - min) + min))
-
-let () =
-  add_builtin "random.bool" ~cat:Bool ~descr:"Generate a random value."
-    [] Lang.bool_t
-    (fun _ -> Lang.bool (Random.bool ()))
-
-let () =
-  add_builtin "max_int" ~cat:Math ~descr:"Maximal representable integer."
-    ~flags:[Lang.Hidden]
-    [] Lang.int_t
-    (fun _ -> Lang.int max_int)
-
-let () =
-  add_builtin "min_int" ~cat:Math ~descr:"Minimal representable integer."
-    ~flags:[Lang.Hidden]
-    [] Lang.int_t
-    (fun _ -> Lang.int min_int)
-
 (** Comparison and boolean connectives *)
 
 let compare_value a b =
