@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2018 Savonet team
+  Copyright 2003-2019 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
  *****************************************************************************)
 
@@ -30,6 +30,7 @@ let create_encoder ~opus ~comments () =
   in
   let pending = ref [||] in
   let enc = ref None in
+  let started  = ref false in
   let get_enc os = 
     match !enc with
       | Some x -> x
@@ -72,6 +73,7 @@ let create_encoder ~opus ~comments () =
     Ogg_muxer.flush_pages os
   in
   let data_encoder data os _ =
+    started := true;
     let enc = get_enc os in
     let data =
       Array.map (fun buf ->
@@ -96,6 +98,14 @@ let create_encoder ~opus ~comments () =
         (fun channel -> Array.sub channel ret ((Array.length channel) - ret))
         data
   in
+  let empty_data () = { Ogg_muxer.
+    offset = 0;
+    length = 1;
+    data =
+      Array.make
+         (Lazy.force Frame.audio_channels)
+         (Array.make 1 0.)
+  } in
   let end_of_page p =
     let granulepos = Ogg.Page.granulepos p in
     if granulepos < Int64.zero then
@@ -105,6 +115,9 @@ let create_encoder ~opus ~comments () =
   in
   let end_of_stream os =
     let enc = get_enc os in
+    (* Assert that at least some data was encoded.. *)
+    if not !started then
+      data_encoder (empty_data ()) os ();
     Opus.Encoder.eos enc
   in
   {
