@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2018 Savonet team
+  Copyright 2003-2019 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
  *****************************************************************************)
 
@@ -248,10 +248,17 @@ struct
                 \"polling\" (attempting to connect to the HTTP stream) \
                 or \"connected <url>\" (connected to <url>, buffering or \
                 playing back the stream)."
-         (Tutils.mutexify socket_m (fun _ ->
-           match socket with
-             | Some (_,_,url) -> "connected " ^ url
-             | None -> if relaying then "polling" else "stopped")) ;
+         (fun _ ->
+           match Mutex.try_lock socket_m with
+             | false -> "A state change is currently happening. Try later!"
+             | true ->
+               let ret =
+                 match socket with
+                   | Some (_,_,url) -> "connected " ^ url
+                   | None -> if relaying then "polling" else "stopped"
+               in
+               Mutex.unlock socket_m;
+               ret);
       self#register_command "buffer_length" ~usage:"buffer_length"
                             ~descr:"Get the buffer's length, in seconds."
         (fun _ -> Printf.sprintf "%.2f" (Frame.seconds_of_audio self#length))
