@@ -2,7 +2,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2018 Savonet team
+  Copyright 2003-2019 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
  *****************************************************************************)
 open Dtools
@@ -316,11 +316,15 @@ let handle_client socket ip =
                  Duppy.Monad.bind (Duppy_c.wait opts.condition opts.mutex)
                    (fun () -> run opts.resume)
              | Write opts ->
+                 (* Make sure write are synchronous by setting TCP_NODELAY off and off. *)
+                 Unix.setsockopt socket Unix.TCP_NODELAY false;
                  Duppy.Monad.bind
                    (Duppy.Monad.Io.write ?timeout: (Some (get_timeout ()))
                       ~priority: Tutils.Non_blocking h
                       (Bytes.of_string opts.payload))
-                   (fun () -> run opts.after)
+                   (fun () ->
+                     Unix.setsockopt socket Unix.TCP_NODELAY true;
+                     run opts.after)
              | Read opts ->
                  let __pa_duppy_0 =
                    Duppy.Monad.Io.read ?timeout: (Some (get_timeout ()))
